@@ -164,7 +164,7 @@ class Robot():
         True
         """
 
-        return not self.is_front_clear()
+        return not self.front_is_clear()
     
     def report(self, msg):
         """ Reports out a message.
@@ -197,7 +197,7 @@ class Robot():
         """
         self.world_model.incr_instruction()
         cell =  self.cell()
-        if self.is_front_clear():
+        if self.front_is_clear():
             if cell.has_goal_wall(self.dir) :
                 cell.add_wall(self.dir, self.world.js_call)
         else:
@@ -215,7 +215,7 @@ class Robot():
         """
 
         self.world_model.incr_instruction()
-        if not self.is_front_clear():
+        if not self.front_is_clear():
             self.cell().remove_wall(self.dir, self.world.js_call)
         else:
             print_error("No Wall exists")
